@@ -32,6 +32,8 @@
 #' @param fn Function for custom formatting. Accepts a vector and returns a character vector of the same length.
 #' @param quarto Logical. Enable Quarto data processing and wrap cell content in a `data-qmd` span (HTML) or `\QuartoMarkdownBase64{}` macro (LaTeX). See warnings in the Global Options section below.
 #' @param sprintf String passed to the `?sprintf` function to format numbers or interpolate strings with a user-defined pattern (similar to the `glue` package, but using Base R).
+#' @param linebreak NULL or a single string. If it is a string, replaces that string with appropriate line break sequences depending on the output format (HTML: `<br>`, LaTeX: `\\\\`, Typst: `\\ `). Markdown output is excluded from line break replacement.
+#' @param output Apply formatting only if the `tt()` object is rendered in the specified format. One of "latex", "html", "typst", or "markdown". If `NULL` (default), apply formatting regardless of the output format.
 #' @inheritParams tt
 #' @inheritParams style_tt
 #' @template global_options
@@ -69,6 +71,20 @@
 #' x <- tt(data.frame(Text = c("_italicized text_", "__bold text__")))
 #' format_tt(x, markdown = TRUE)
 #'
+#' # Line breaks using linebreak argument
+#' d <- data.frame(Text = "First line<br>Second line")
+#' tt(d) |> format_tt(linebreak = "<br>")
+#'
+#' # Non-standard evaluation (NSE)
+#' dat <- data.frame(
+#'   w = c(143002.2092, 201399.181, 100188.3883),
+#'   x = c(1.43402, 201.399, 0.134588),
+#'   y = as.Date(c(897, 232, 198), origin = "1970-01-01"),
+#'   z = c(TRUE, TRUE, FALSE)
+#' )
+#' tt(dat) |>
+#'   format_tt(i = w > 150000, j = w, digits = 0, num_mark_big = ",")
+#'
 #' tab <- data.frame(a = c(NA, 1, 2), b = c(3, NA, 5))
 #' tt(tab) |> format_tt(replace = "-")
 #'
@@ -79,29 +95,30 @@
 #' tt(dat) |> format_tt(escape = TRUE)
 #'
 format_tt <- function(
-  x,
-  i = NULL,
-  j = NULL,
-  digits = get_option("tinytable_format_digits", default = NULL),
-  num_fmt = get_option("tinytable_format_num_fmt", default = "significant"),
-  num_zero = get_option("tinytable_format_num_zero", default = FALSE),
-  num_suffix = get_option("tinytable_format_num_suffix", default = FALSE),
-  num_mark_big = get_option("tinytable_format_num_mark_big", default = ""),
-  num_mark_dec = get_option(
-    "tinytable_format_num_mark_dec",
-    default = getOption("OutDec", default = ".")
-  ),
-  date = get_option("tinytable_format_date", default = NULL),
-  bool = get_option("tinytable_format_bool", default = NULL),
-  math = get_option("tinytable_format_math", default = FALSE),
-  other = get_option("tinytable_format_other", default = NULL),
-  replace = get_option("tinytable_format_replace", default = FALSE),
-  escape = get_option("tinytable_format_escape", default = FALSE),
-  markdown = get_option("tinytable_format_markdown", default = FALSE),
-  quarto = get_option("tinytable_format_quarto", default = FALSE),
-  fn = get_option("tinytable_format_fn", default = NULL),
-  sprintf = get_option("tinytable_format_sprintf", default = NULL)
-) {
+    x,
+    i = NULL,
+    j = NULL,
+    digits = get_option("tinytable_format_digits", default = NULL),
+    num_fmt = get_option("tinytable_format_num_fmt", default = "significant"),
+    num_zero = get_option("tinytable_format_num_zero", default = FALSE),
+    num_suffix = get_option("tinytable_format_num_suffix", default = FALSE),
+    num_mark_big = get_option("tinytable_format_num_mark_big", default = ""),
+    num_mark_dec = get_option(
+      "tinytable_format_num_mark_dec",
+      default = getOption("OutDec", default = ".")
+    ),
+    date = get_option("tinytable_format_date", default = NULL),
+    bool = get_option("tinytable_format_bool", default = NULL),
+    math = get_option("tinytable_format_math", default = FALSE),
+    other = get_option("tinytable_format_other", default = NULL),
+    replace = get_option("tinytable_format_replace", default = FALSE),
+    escape = get_option("tinytable_format_escape", default = FALSE),
+    markdown = get_option("tinytable_format_markdown", default = FALSE),
+    quarto = get_option("tinytable_format_quarto", default = FALSE),
+    fn = get_option("tinytable_format_fn", default = NULL),
+    sprintf = get_option("tinytable_format_sprintf", default = NULL),
+    linebreak = get_option("tinytable_format_linebreak", default = NULL),
+    output = get_option("tinytable_format_output", default = NULL)) {
   assert_integerish(digits, len = 1, null.ok = TRUE)
   assert_choice(
     num_fmt,
@@ -117,12 +134,18 @@ format_tt <- function(
   assert_flag(markdown)
   assert_flag(quarto)
   assert_function(fn, null.ok = TRUE)
+  assert_choice(output, c("latex", "html", "typst", "markdown"), null.ok = TRUE)
   assert_string(sprintf, null.ok = TRUE)
+  assert_string(linebreak, null.ok = TRUE)
   replace <- sanitize_replace(replace)
   sanity_num_mark(digits, num_mark_big, num_mark_dec)
 
   out <- x
 
+  # non-standard evaluation before anything else
+  tmp <- nse_i_j(x, i_expr = substitute(i), j_expr = substitute(j), pf = parent.frame())
+  list2env(tmp, environment())
+
   if (inherits(out, "tinytable")) {
     cal <- call(
       "format_tt_lazy",
@@ -143,7 +166,9 @@ format_tt <- function(
       escape = escape,
       markdown = markdown,
       quarto = quarto,
-      other = other
+      other = other,
+      linebreak = linebreak,
+      output = output
     )
     out@lazy_format <- c(out@lazy_format, list(cal))
   } else {
@@ -166,7 +191,9 @@ format_tt <- function(
       other = other,
       escape = escape,
       quarto = quarto,
-      markdown = markdown
+      markdown = markdown,
+      linebreak = linebreak,
+      output = output
     )
   }
 
@@ -175,26 +202,27 @@ format_tt <- function(
 
 
 format_tt_lazy <- function(
-  x,
-  i,
-  j,
-  digits,
-  num_fmt,
-  num_zero,
-  num_suffix,
-  num_mark_big,
-  num_mark_dec,
-  replace,
-  fn,
-  sprintf,
-  date_format,
-  bool,
-  math,
-  escape,
-  markdown,
-  quarto,
-  other
-) {
+    x,
+    i,
+    j,
+    digits,
+    num_fmt,
+    num_zero,
+    num_suffix,
+    num_mark_big,
+    num_mark_dec,
+    replace,
+    fn,
+    sprintf,
+    date_format,
+    bool,
+    math,
+    escape,
+    markdown,
+    quarto,
+    other,
+    linebreak,
+    output) {
   if (inherits(x, "tbl_df")) {
     assert_dependency("tibble")
     x_is_tibble <- TRUE
@@ -203,6 +231,12 @@ format_tt_lazy <- function(
     x_is_tibble <- FALSE
   }
 
+  if (inherits(x, "tinytable") && !is.null(output)) {
+    if (!identical(x@output, output)) {
+      return(x)
+    }
+  }
+
   # important for tabulator
   if (!is.null(bool) && inherits(x, "tinytable")) {
     x@tabulator_format_bool <- TRUE
@@ -348,6 +382,25 @@ format_tt_lazy <- function(
     )
   }
 
+  # linebreak before replace and escape
+  if (!is.null(linebreak)) {
+    if (inherits(x, "tinytable")) {
+      output_format <- x@output
+    } else {
+      output_format <- NULL
+    }
+    x <- apply_format(
+      x = x,
+      i = i,
+      j = j,
+      format_fn = format_vector_linebreak,
+      components = components,
+      original_data = FALSE,
+      linebreak = linebreak,
+      output = output_format
+    )
+  }
+
   # replace before escape, otherwise overaggressive removal
   x <- apply_format(
     x = x,
@@ -382,15 +435,6 @@ format_tt_lazy <- function(
       original_data = FALSE,
       output = o
     )
-
-    x <- apply_colnames(
-      x,
-      i,
-      j,
-      format_vector_escape,
-      components = components,
-      output = o
-    )
   }
 
   # markdown and quarto at the very end
