@@ -9,12 +9,9 @@ dest_dir <- tempdir()
 dest_pdf <- file.path(dest_dir, "out.pdf")
 dest_log <- file.path(dest_dir, "somelog.log")
 
-expect_warning(
-  tt(x) |>
-    theme_tt("resize") |>
-    save_tt(dest_pdf, overwrite = TRUE),
-  "Table width is too small"
-)
+tt(x) |>
+  theme_latex(resize_direction = "down") |>
+  save_tt(dest_pdf, overwrite = TRUE)
 
 # logfiles are automatically deleted
 expect_equal(
@@ -25,12 +22,9 @@ expect_equal(
 # logfiles that exist before call to tinytex are left untouched
 cat("some content", file = dest_log)
 
-expect_warning(
-  tt(x) |>
-    theme_tt("resize") |>
-    save_tt(dest_pdf, overwrite = TRUE),
-  "Table width is too small"
-)
+tt(x) |>
+  theme_latex(resize_direction = "down") |>
+  save_tt(dest_pdf, overwrite = TRUE)
 
 expect_true("somelog.log" %in% list.files(dest_dir))
 
